.. raw :: html

    <!-- Generated by generate_authors_table.py -->
    <div class="sk-authors-container">
    <style>
      img.avatar {border-radius: 10px;}
    </style>
    <div>
    <a href='https://github.com/laurburke'><img src='https://avatars.githubusercontent.com/u/35973528?v=4' class='avatar' /></a> <br />
    <p>Lauren Burke-McCarthy</p>
    </div>
    <div>
    <a href='https://github.com/francoisgoupil'><img src='https://avatars.githubusercontent.com/u/98105626?v=4' class='avatar' /></a> <br />
    <p>François Goupil</p>
    </div>
    </div>
